style "panelbg"
{
  xthickness            			= 0
  ythickness            			= 0
 bg_pixmap[NORMAL]			= "panel-bg.png"
 #bg_pixmap[NORMAL]			= "panel-bg-top.png"
}
class "*Panel*" style "panelbg"
widget_class "*Mail*" style "panelbg"

style "panelbuttons" = "default"
{
xthickness            			= 1
ythickness            			= 1
GtkWidget::focus_padding = 2
engine "pixmap" {
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			state				= NORMAL
			file            			= "panel-normal.png"
			border          			= { 8, 8, 7, 7 }
			stretch         			= TRUE
		}
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			state				= PRELIGHT
			file            			= "panel-prelight.png"
			border          			= { 8, 8, 7, 7 }
			stretch         			= TRUE
		}
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			shadow				= OUT
			state				= PRELIGHT
			file            			= "panel-prelight.png"
			border          			= { 8, 8, 7, 7 }
			stretch         			= TRUE
		}
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			shadow				= IN
			state				= PRELIGHT
			file            			= "panel-prelight.png"
			border          			= { 8, 8, 7, 7 }
			stretch         			= TRUE
		}
		image
		{
			function        			= BOX
			recolorable     		= TRUE
			state				= ACTIVE
			file            			= "panel-pressed.png"
			border          			= { 8, 8, 7, 7 }
			stretch         			= TRUE
		} 
	}
}
widget_class "*Panel*GtkToggleButton" style "panelbuttons"
widget_class "*Panel*GtkButton" style "panelbuttons"


